FilesData class
Constructors
-
FilesData({required List<
MultipartFileData> files, String filesNameParameter = 'file[]'})
Properties
-
files
→ List<
MultipartFileData> -
final
- filesNameParameter → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited