Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
delete(String path, {dynamic data, Map<String, dynamic>? queryParameters, bool external = false, })
→ Future<Either<HttpResponseError, HttpResponse>>
-
-
get(String path, {Map<String, dynamic>? queryParameters, bool noCache = false, bool external = false, })
→ Future<Either<HttpResponseError, HttpResponse>>
-
-
init()
→ void
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(String path, {dynamic data, Map<String, dynamic>? queryParameters, bool external = false, })
→ Future<Either<HttpResponseError, HttpResponse>>
-
-
post(String path, {dynamic data, Map<String, dynamic>? queryParameters, Options? options, bool retryOnTokenExpired = true, bool external = false, })
→ Future<Either<HttpResponseError, HttpResponse>>
-
-
postImages(String path, {required Map<String, dynamic> data, required FilesData filesData, bool external = false, })
→ Future<Either<HttpResponseError, HttpResponse>>
-
-
put(String path, {dynamic data, Map<String, dynamic>? queryParameters, bool external = false})
→ Future<Either<HttpResponseError, HttpResponse>>
-
-
toString()
→ String
-
A string representation of this object.
inherited